@@ -3,7 +3,7 @@
  * Collection of useful common types and macros definitions
  *****************************************************************************
  * Copyright (C) 1998, 1999, 2000 VideoLAN
- * $Id: common.h,v 1.94 2002/04/17 11:43:31 sam Exp $
+ * $Id: common.h,v 1.108 2002/05/20 22:36:42 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@via.ecp.fr>
  *          Vincent Seguin <seguin@via.ecp.fr>
@@ -113,11 +113,6 @@ typedef s64 mtime_t;
  * Classes declaration
  *****************************************************************************/
 
-/* System */
-struct main_sys_s;
-
-typedef struct main_sys_s *             p_main_sys_t;
-
 /* Plugins */
 struct plugin_bank_s;
 struct plugin_info_s;
@@ -206,6 +201,8 @@ struct input_buffers_s;
 struct network_socket_s;
 struct intf_subscription_s;
 
+typedef struct iso639_lang_s iso639_lang_t;
+
 /*****************************************************************************
  * Macros and inline functions
  *****************************************************************************/
@@ -338,7 +335,7 @@ struct intf_subscription_s;
 #else
 #   define hton16      htons
 #   define hton32      htonl
-    static __inline__ u64 __hton64( u64 i )
+    static inline u64 __hton64( u64 i )
     {
         return ((u64)(htonl((i) & 0xffffffff)) << 32)
                 | htonl(((i) >> 32) & 0xffffffff );
@@ -378,13 +375,15 @@ struct intf_subscription_s;
     /* Some systems have memalign() but no declaration for it */
     void * memalign( size_t align, size_t size );
 
-#   define vlc_memalign(align,size,pp_orig) \
+#   define vlc_memalign(pp_orig,align,size) \
     ( *(pp_orig) = memalign( align, size ) )
 
 #else /* We don't have any choice but to align manually */
-#   define vlc_memalign(align,size,pp_orig) \
-    (( *(pp_orig) = malloc( size + align - 1 )) ? \
-        (void *)( (((unsigned long)*(pp_orig)) + 15) & ~0xFUL ) : NULL )
+#   define vlc_memalign(pp_orig,align,size) \
+    (( *(pp_orig) = malloc( size + align - 1 )) \
+        ? (void *)( (((unsigned long)*(pp_orig)) + (unsigned long)(align-1) ) \
+                       & (~(unsigned long)(align-1)) ) \
+        : NULL )
 
 #endif
 
@@ -500,26 +499,46 @@ typedef __int64 off_t;
 #   define N_(String) (String)
 #endif
 
+/*****************************************************************************
+ * Debug macros
+ *****************************************************************************/
+/* ASSERT: this macro is used to test that a pointer is not nul. It inserts
+ * the needed code when the program is compiled with the debug option, but
+ * does nothing when not in debug mode. */
+#ifdef DEBUG
+#   define ASSERT(p_Mem)                                                      \
+    if (!(p_Mem))                                                             \
+        intf_ErrMsg("Void pointer error: "                                    \
+                    "%s line %d (variable %s at address %p)\n",               \
+                     __FILE__, __LINE__, #p_Mem, &p_Mem);
+#else
+#   define ASSERT(p_Mem)
+#endif
+
 /*****************************************************************************
  * Plug-in stuff
  *****************************************************************************/
 typedef struct module_symbols_s
 {
     struct main_s* p_main;
-    struct main_sys_s* p_main_sys;
     struct module_bank_s* p_module_bank;
     struct input_bank_s* p_input_bank;
     struct aout_bank_s*  p_aout_bank;
     struct vout_bank_s*  p_vout_bank;
 
-    int    ( * config_GetIntVariable ) ( const char * );
-    char * ( * config_GetPszVariable ) ( const char * );
-    void   ( * config_PutIntVariable ) ( const char *, int );
-    void   ( * config_PutPszVariable ) ( const char *, char * );
-    int    ( * config_LoadConfigFile ) ( const char * );
-    int    ( * config_SaveConfigFile ) ( const char * );
+    int    ( * config_GetIntVariable )   ( const char * );
+    float  ( * config_GetFloatVariable ) ( const char * );
+    char * ( * config_GetPszVariable )   ( const char * );
+    void   ( * config_PutIntVariable )   ( const char *, int );
+    void   ( * config_PutFloatVariable ) ( const char *, float );
+    void   ( * config_PutPszVariable )   ( const char *, char * );
+    int    ( * config_LoadConfigFile )   ( const char * );
+    int    ( * config_SaveConfigFile )   ( const char * );
     struct module_config_s * ( * config_FindConfig ) ( const char * );
-    struct module_config_s * ( * config_Duplicate ) ( struct module_s * );
+    struct module_config_s * ( * config_Duplicate ) ( struct module_config_s* );
+    void   ( * config_SetCallbacks )     ( struct module_config_s *,
+                                           struct module_config_s * );
+    void   ( * config_UnsetCallbacks )   ( struct module_config_s * );
 
     struct intf_subscription_s * ( * intf_MsgSub ) ( void );
     void ( * intf_MsgUnsub )   ( struct intf_subscription_s * );
@@ -560,6 +579,8 @@ typedef struct module_symbols_s
     int  ( * input_ChangeProgram )  ( struct input_thread_s *, u16 );
     struct es_descriptor_s * ( * input_FindES ) ( struct input_thread_s *,
                                                   u16 );
+    struct pgrm_descriptor_s * ( * input_FindProgram ) 
+                                    ( struct input_thread_s *, u16 );
     struct es_descriptor_s * ( * input_AddES ) ( struct input_thread_s *,
                                       struct pgrm_descriptor_s *, u16, size_t );
     void ( * input_DelES )          ( struct input_thread_s *,
@@ -605,16 +626,24 @@ typedef struct module_symbols_s
     ssize_t ( * input_ReadTS )      ( struct input_thread_s *,
                                       struct data_packet_s ** );
     void ( * input_DemuxTS )        ( struct input_thread_s *,
-                                      struct data_packet_s * );
-    void ( * input_DemuxPSI )       ( struct input_thread_s *,
                                       struct data_packet_s *,
-                                      struct es_descriptor_s *, 
-                                      boolean_t, boolean_t );
+                                      void(* pf_psi_callback) 
+                                           ( struct input_thread_s *,
+                                             struct data_packet_s  *,
+                                             struct es_descriptor_s *,
+                                             boolean_t ) );
+    void ( * input_ClockManageRef )      ( struct input_thread_s *,
+                                           struct pgrm_descriptor_s *,
+                                           mtime_t );
     int ( * input_ClockManageControl )   ( struct input_thread_s *,
                                            struct pgrm_descriptor_s *,
                                            mtime_t );
+    mtime_t ( *input_ClockGetTS )       ( struct input_thread_s *,
+                                             struct  pgrm_descriptor_s *, 
+                                             mtime_t );
     void ( * input_FDSeek )         ( struct input_thread_s *, off_t );
     void ( * input_FDClose )        ( struct input_thread_s * );
+    void ( * input_FDNetworkClose ) ( struct input_thread_s * );
     ssize_t ( * input_FDRead )          ( struct input_thread_s *, byte_t *,
                                       size_t );
     ssize_t ( * input_FDNetworkRead )   ( struct input_thread_s *, byte_t *,
@@ -659,6 +688,7 @@ typedef struct module_symbols_s
                                       struct picture_s *, mtime_t );
     void  ( * vout_PlacePicture )   ( struct vout_thread_s *, int, int,
                                       int *, int *, int *, int * );
+    int   ( * vout_ChromaCmp )      ( u32, u32 );
 
     struct subpicture_s * (* vout_CreateSubPicture)
                                         ( struct vout_thread_s *, int, int );
@@ -673,14 +703,17 @@ typedef struct module_symbols_s
     void ( * CurrentPTS )           ( struct bit_stream_s *, mtime_t *,
                                       mtime_t * );
 
-    char * ( * DecodeLanguage ) ( u16 );
+    const iso639_lang_t * ( * GetLang_1 ) ( const char * );
+    const iso639_lang_t * ( * GetLang_2T ) ( const char * );
+    const iso639_lang_t * ( * GetLang_2B ) ( const char * );
+    const char * ( * DecodeLanguage ) ( u16 );
 
     struct module_s * ( * module_Need )   ( int, char *, void * );
     void              ( * module_Unneed ) ( struct module_s * );
 
 } module_symbols_t;
 
-#ifdef PLUGIN
+#ifdef __PLUGIN__
 extern module_symbols_t* p_symbols;
 #endif
 
