@@ -4,7 +4,7 @@
  * modules.
  *****************************************************************************
  * Copyright (C) 1999, 2000, 2001 VideoLAN
- * $Id: netutils.h,v 1.18 2001/12/30 07:09:54 sam Exp $
+ * $Id: netutils.h,v 1.19 2002/04/24 00:36:24 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Henri Fallon <henri@videolan.org>
@@ -33,7 +33,7 @@
 struct sockaddr_in;
 int   network_BuildAddr       ( struct sockaddr_in *, char *, int ); 
 
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 int   network_ChannelJoin     ( int );
 int   network_ChannelCreate   ( void );
 #else
