@@ -1,7 +1,7 @@
 /* dvd_es.c: functions to find and select ES
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: dvd_es.c,v 1.11 2002/05/18 14:03:13 gbazin Exp $
+ * $Id: dvd_es.c,v 1.11.2.1 2002/06/27 19:44:54 sam Exp $
  *
  * Author: Stphane Borel <stef@via.ecp.fr>
  *
@@ -310,8 +310,15 @@ void DVDLaunchDecoders( input_thread_t * p_input )
         }
         if( i_spu > 0 )
         {
-            i_spu += p_dvd->p_ifo->vts.manager_inf.i_audio_nb;
-            input_SelectES( p_input, p_input->stream.pp_es[i_spu] );
-        }
+	  int i=0,j=0;
+	  for (i=0; i < p_input->stream.i_es_number; i++ ) {
+	    if ( p_input->stream.pp_es[i]->i_type == DVD_SPU_ES ) {
+	      j++;
+	      if ( i_spu == j ) break;
+	    }
+	  }
+	  if (i_spu == j )
+	    input_SelectES( p_input, p_input->stream.pp_es[i] );
+	}
     }
 }
