@@ -2,7 +2,7 @@
  * intf_qt.cpp: Qt interface
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: intf_qt.cpp,v 1.9 2001/12/07 18:33:08 sam Exp $
+ * $Id: intf_qt.cpp,v 1.13 2002/04/04 15:35:09 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -24,24 +24,15 @@
 extern "C"
 {
 
-#define MODULE_NAME qt
-#include "modules_inner.h"
-
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include "defs.h"
-
 #include <errno.h>                                                 /* ENOMEM */
 #include <stdlib.h>                                                /* free() */
 #include <string.h>                                            /* strerror() */
 #include <stdio.h>
 
-#include "common.h"
-#include "intf_msg.h"
-#include "threads.h"
-#include "mtime.h"
-#include "tests.h"
+#include <videolan/vlc.h>
 
 #include "stream_control.h"
 #include "input_ext-intf.h"
@@ -49,9 +40,6 @@ extern "C"
 #include "intf_playlist.h"
 #include "interface.h"
 
-#include "modules.h"
-#include "modules_export.h"
-
 } /* extern "C" */
 
 #include <qapplication.h>
@@ -113,7 +101,7 @@ private slots:
     void Manage( void );
 
     void FileOpen  ( void );
-    void FileQuit  ( void ) { p_intf->b_die = 1; };
+    void FileQuit  ( void ) { qApp->quit(); };
 
     void PlaybackPlay  ( void );
     void PlaybackPause ( void );
@@ -139,11 +127,7 @@ private:
     QLabel     *p_date;
 };
 
-#ifdef BUILTIN
-#   include "BUILTIN_intf_qt.moc"
-#else
-#   include "intf_qt.moc"
-#endif
+#include "intf_qt.moc"
 
 #define SLIDER_MIN    0x00000
 #define SLIDER_MAX    0x10000
@@ -162,7 +146,6 @@ typedef struct intf_sys_s
 /*****************************************************************************
  * Local prototypes.
  *****************************************************************************/
-static int  intf_Probe     ( probedata_t *p_data );
 static int  intf_Open      ( intf_thread_t *p_intf );
 static void intf_Close     ( intf_thread_t *p_intf );
 static void intf_Run       ( intf_thread_t *p_intf );
@@ -176,7 +159,6 @@ extern "C"
 
 void _M( intf_getfunctions )( function_list_t * p_function_list )
 {
-    p_function_list->pf_probe = intf_Probe;
     p_function_list->functions.intf.pf_open  = intf_Open;
     p_function_list->functions.intf.pf_close = intf_Close;
     p_function_list->functions.intf.pf_run   = intf_Run;
@@ -184,27 +166,6 @@ void _M( intf_getfunctions )( function_list_t * p_function_list )
 
 }
 
-/*****************************************************************************
- * intf_Probe: probe the interface and return a score
- *****************************************************************************
- * This function tries to initialize Qt and returns a score to the
- * plugin manager so that it can select the best plugin.
- *****************************************************************************/
-static int intf_Probe( probedata_t *p_data )
-{
-    if( TestMethod( INTF_METHOD_VAR, "qt" ) )
-    {
-        return( 999 );
-    }
-
-    if( TestProgram( "qvlc" ) )
-    {
-        return( 180 );
-    }
-
-    return( 80 );
-}
-
 /*****************************************************************************
  * intf_Open: initialize and create window
  *****************************************************************************/
@@ -404,15 +365,15 @@ IntfWindow::~IntfWindow( void )
  *****************************************************************************/
 void IntfWindow::DateDisplay( int i_range )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
         char psz_time[ OFFSETTOTIME_MAX_SIZE ];
 
-        vlc_mutex_lock( &p_intf->p_input->stream.stream_lock );
-        p_date->setText( input_OffsetToTime( p_intf->p_input, psz_time,
-               ( p_intf->p_input->stream.p_selected_area->i_size * i_range )
+        vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
+        p_date->setText( input_OffsetToTime( p_input_bank->pp_input[0], psz_time,
+               ( p_input_bank->pp_input[0]->stream.p_selected_area->i_size * i_range )
                    / SLIDER_MAX ) );
-        vlc_mutex_unlock( &p_intf->p_input->stream.stream_lock );
+        vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
     }
 }
 
@@ -446,7 +407,7 @@ void IntfWindow::About( void )
 {
     QMessageBox::about( this, "About",
         "VideoLAN Client\n"
-        "(C) 1996, 1997, 1998, 1999, 2000, 2001 - the VideoLAN Team\n"
+        "(C) 1996, 1997, 1998, 1999, 2000, 2001, 2002 - the VideoLAN Team\n"
         "\n"
         "This is the VideoLAN client, a DVD and MPEG player.\n"
         "It can play MPEG and MPEG 2 files from a file "
@@ -464,11 +425,11 @@ void IntfWindow::About( void )
 void IntfWindow::Manage( void )
 {
     /* Manage the slider */
-    if( p_intf->p_input != NULL && p_intf->p_input->stream.b_seekable )
+    if( p_input_bank->pp_input[0] != NULL && p_input_bank->pp_input[0]->stream.b_seekable )
     {
         int i_value = p_slider->value();
 
-#define p_area p_intf->p_input->stream.p_selected_area
+#define p_area p_input_bank->pp_input[0]->stream.p_selected_area
         /* If the user hasn't touched the slider since the last time,
          * then the input can safely change it */
         if( i_value == p_slider->oldvalue() )
@@ -484,7 +445,7 @@ void IntfWindow::Manage( void )
         {
             off_t i_seek = ( i_value * p_area->i_size ) / SLIDER_MAX;
 
-            input_Seek( p_intf->p_input, i_seek );
+            input_Seek( p_input_bank->pp_input[0], i_seek );
 
             /* Update the old value */
             p_slider->setOldValue( i_value );
@@ -499,17 +460,13 @@ void IntfWindow::Manage( void )
         p_intf->b_menu_change = 0;
     }
 
-    /* Manage core vlc functions through the callback */
-    p_intf->pf_manage( p_intf );
-
     if( p_intf->b_die )
     {
-        /* Prepare to die, young Skywalker */
         qApp->quit();
-
-        /* Just in case */
-        return;
     }
+
+    /* Manage core vlc functions through the callback */
+    p_intf->pf_manage( p_intf );
 }
 
 /*****************************************************************************
@@ -517,9 +474,9 @@ void IntfWindow::Manage( void )
  *****************************************************************************/
 void IntfWindow::PlaybackPlay( void )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_PLAY );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_PLAY );
     }
 }
 
@@ -528,9 +485,9 @@ void IntfWindow::PlaybackPlay( void )
  *****************************************************************************/
 void IntfWindow::PlaybackPause( void )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_PAUSE );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_PAUSE );
     }
 }
 
@@ -539,9 +496,9 @@ void IntfWindow::PlaybackPause( void )
  *****************************************************************************/
 void IntfWindow::PlaybackSlow( void )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_SLOWER );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_SLOWER );
     }
 }
 
@@ -550,9 +507,9 @@ void IntfWindow::PlaybackSlow( void )
  *****************************************************************************/
 void IntfWindow::PlaybackFast( void )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
-        input_SetStatus( p_intf->p_input, INPUT_STATUS_FASTER );
+        input_SetStatus( p_input_bank->pp_input[0], INPUT_STATUS_FASTER );
     }
 }
 
@@ -561,12 +518,12 @@ void IntfWindow::PlaybackFast( void )
  *****************************************************************************/
 void IntfWindow::PlaylistPrev( void )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
         /* FIXME: temporary hack */
         intf_PlaylistPrev( p_main->p_playlist );
         intf_PlaylistPrev( p_main->p_playlist );
-        p_intf->p_input->b_eof = 1;
+        p_input_bank->pp_input[0]->b_eof = 1;
     }
 }
 
@@ -575,10 +532,10 @@ void IntfWindow::PlaylistPrev( void )
  *****************************************************************************/
 void IntfWindow::PlaylistNext( void )
 {
-    if( p_intf->p_input != NULL )
+    if( p_input_bank->pp_input[0] != NULL )
     {
         /* FIXME: temporary hack */
-        p_intf->p_input->b_eof = 1;
+        p_input_bank->pp_input[0]->b_eof = 1;
     }
 }
 
